@@ -1,4 +1,4 @@
-__all__ = ['main', 'metadata']
+__all__ = ['main', 'metadata', 'console']
 __author__ = 'Christian S. Perone'
 __author_url__ = 'http://pyevolve.sourceforge.net/wordpress'
-__version__ = '0.3'
+__version__ = '0.4'
