@@ -97,6 +97,40 @@ def get_pypi_releases(dist_name):
 
     return ret
 
+def get_pypi_search(spec, operator='or'):
+    """Search the package database using the indicated search spec
+
+    The spec may include any of the keywords described in the above list
+    (except 'stable_version' and 'classifiers'), for example: {'description': 'spam'}
+    will search description fields. Within the spec, a field's value can be a string
+    or a list of strings (the values within the list are combined with an OR), for
+    example: {'name': ['foo', 'bar']}. Valid keys for the spec dict are listed here.
+
+    name
+    version
+    author
+    author_email
+    maintainer
+    maintainer_email
+    home_page
+    license
+    summary
+    description
+    keywords
+    platform
+    download_url
+    
+    Arguments for different fields are combined using either "and" (the default) or "or".
+    Example: search({'name': 'foo', 'description': 'bar'}, 'or'). The results are
+    returned as a list of dicts {'name': package name, 'version': package release version,
+    'summary': package release summary}
+    browse(classifiers)
+    """
+    pypi = get_pypi_proxy()
+    ret = pypi.search(spec, operator)
+    ret.sort(key=lambda v: v['_pypi_ordering'], reverse=True)
+    return ret
+
 
 @app.route('/pypi/check_update/<dist_name>')
 def check_pypi_update(dist_name):
@@ -191,6 +225,18 @@ def index():
 
     return render_template('system_information.html', **data)
 
+@app.route('/console_scripts')
+def console_scripts():
+    """ Entry point for the global console scripts """
+    data = {}
+    data.update(get_shared_data())
+    data['menu_console_scripts'] = 'active'
+    data['breadpath'] = [Crumb('Console Scripts')]
+
+    entry_console = get_pkg_res().iter_entry_points('console_scripts')
+    data['scripts'] = entry_console
+
+    return render_template('console_scripts.html', **data)
 
 @app.route('/about')
 def about():
@@ -245,6 +291,7 @@ def distribution(dist_name=None):
         pass
 
     data['distinfo'] = distinfo
+    data['entry_map'] = pkg_dist.get_entry_map()
 
     if parts is not None:
         data['description_render'] = parts['body']
@@ -256,7 +303,7 @@ def run_main():
     """ The main entry-point of Stallion. """
 
     print('Stallion %s - Python Package Manager' % (stallion.__version__,))
-    print('By %s 2011\n' % (stallion.__author__,))
+    print('By %s 2013\n' % (stallion.__author__,))
     parser = OptionParser()
 
     parser.add_option('-s', '--host', dest='host',
